import { OnInit, AfterContentInit, QueryList, TemplateRef, SimpleChanges, OnChanges, ChangeDetectorRef, EventEmitter } from '@angular/core';
import { AfterViewInit } from '@angular/core';
import { MatSort } from '@angular/material/sort';
import { BehaviorSubject } from 'rxjs';
import { MatTable, MatTableDataSource } from '@angular/material/table';
import { MatPaginator, PageEvent } from '@angular/material/paginator';
import * as i0 from "@angular/core";
export interface SdsRowConfig {
    displayedColumns?: string[];
    expandOnClick?: boolean;
    highlightOnHover?: boolean;
    rowClickNavigate?: string;
}
export interface SdsHeaderRowConfig extends SdsRowConfig {
    sticky?: boolean;
}
export interface SdsFooterRowConfig extends SdsRowConfig {
    sticky?: boolean;
}
export declare enum SdsTableHeaderColor {
    InfoLighter = "header-info-lighter",
    AccentCoolLight = "header-accent-cool-light",
    PrimaryLighter = "header-primary-lighter"
}
export declare class SdsTableRowComponent {
    displayedColumns: Array<string>;
    expandOnClick: boolean;
    highlightOnHover: boolean;
    rowClickNavigate: string;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTableRowComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsTableRowComponent, "sds-row", never, { "displayedColumns": { "alias": "displayedColumns"; "required": false; }; "expandOnClick": { "alias": "expandOnClick"; "required": false; }; "highlightOnHover": { "alias": "highlightOnHover"; "required": false; }; "rowClickNavigate": { "alias": "rowClickNavigate"; "required": false; }; }, {}, never, ["*"], false, never>;
}
export declare class SdsTableHeaderRowComponent {
    displayedColumns: Array<string>;
    sticky: boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTableHeaderRowComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsTableHeaderRowComponent, "sds-header-row", never, { "displayedColumns": { "alias": "displayedColumns"; "required": false; }; "sticky": { "alias": "sticky"; "required": false; }; }, {}, never, ["*"], false, never>;
}
export declare class SdsTableFooterRowComponent {
    displayedColumns: Array<string>;
    sticky: boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTableFooterRowComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsTableFooterRowComponent, "sds-footer-row", never, { "displayedColumns": { "alias": "displayedColumns"; "required": false; }; "sticky": { "alias": "sticky"; "required": false; }; }, {}, never, ["*"], false, never>;
}
export declare class SdsTableHeaderCellDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTableHeaderCellDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SdsTableHeaderCellDirective, "sds-table-headercell", never, {}, {}, never, never, false, never>;
}
export declare class SdsTableCellDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTableCellDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SdsTableCellDirective, "sds-table-cell", never, {}, {}, never, never, false, never>;
}
export declare class SdsTableFooterCellDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTableFooterCellDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SdsTableFooterCellDirective, "sds-table-footercell", never, {}, {}, never, never, false, never>;
}
export declare class SdsTableColumnDefComponent implements AfterContentInit {
    columnHeaderCell: TemplateRef<any>;
    columnCell: TemplateRef<any>;
    columnFooterCell: TemplateRef<any>;
    headerCellTemplate: TemplateRef<any>;
    cellTemplate: TemplateRef<any>;
    footerCellTemplate: TemplateRef<any>;
    sdsColumnName: any;
    sticky: boolean;
    stickyEnd: boolean;
    sdsExpandedTemplate: boolean;
    isClickable: boolean;
    ngAfterContentInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTableColumnDefComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsTableColumnDefComponent, "sds-table-column", never, { "sdsColumnName": { "alias": "sdsColumnName"; "required": false; }; "sticky": { "alias": "sticky"; "required": false; }; "stickyEnd": { "alias": "stickyEnd"; "required": false; }; "sdsExpandedTemplate": { "alias": "sdsExpandedTemplate"; "required": false; }; "isClickable": { "alias": "isClickable"; "required": false; }; }, {}, ["headerCellTemplate", "cellTemplate", "footerCellTemplate"], never, false, never>;
}
export declare class SdsTableComponent implements OnInit, AfterContentInit, AfterViewInit, OnChanges {
    private changeDetectorRef;
    /**
     * Data for table
     */
    data: any;
    /**
     * Borderless table
     */
    set borderless(borderless: boolean);
    get borderless(): boolean;
    private _borderless;
    /**
     * Sorting table
     */
    sort: string;
    /**
     * Sorting function override
     */
    sortFn: any;
    /**
     * Name of table - used in setting element id values
     */
    tableName: string;
    /**
     * Pagination table
     */
    set pagination(pagination: boolean);
    get pagination(): boolean;
    private _pagination;
    /**
     * Expansion table
     */
    set expansion(expansion: boolean);
    get expansion(): boolean;
    private _expansion;
    expandedAriaLabel: string;
    collapsedAriaLabel: string;
    headerColor: SdsTableHeaderColor;
    expansionClicked: EventEmitter<any>;
    rowClicked: EventEmitter<number>;
    dataSource: MatTableDataSource<any>;
    expandedElement: any;
    table: MatTable<any>;
    sdsTableRowComponent: SdsTableRowComponent;
    sdsTableHeaderRowComponent: SdsTableHeaderRowComponent;
    sdsTableFooterRowComponent: SdsTableFooterRowComponent;
    sdsColumnItems: QueryList<SdsTableColumnDefComponent>;
    matSort: MatSort;
    matPaginator: MatPaginator;
    rowConfig: SdsRowConfig;
    headerRowConfig: SdsHeaderRowConfig;
    footerRowConfig: SdsFooterRowConfig;
    pageEvent: PageEvent;
    top: {
        id: string;
    };
    bottom: {
        id: string;
    };
    page: any;
    pageChange: BehaviorSubject<object>;
    showPagination: boolean;
    totalItems: number;
    constructor(changeDetectorRef: ChangeDetectorRef);
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    typeOf(value: any): "string" | "number" | "bigint" | "boolean" | "symbol" | "undefined" | "object" | "function";
    isArray(obj: any): boolean;
    updateSdsPagination(): void;
    defaultSort(data: any, sortHeaderId: any): any;
    onExpansionClicked(element: any): void;
    get columnsClickable(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsTableComponent, "sds-table", never, { "data": { "alias": "data"; "required": false; }; "borderless": { "alias": "borderless"; "required": false; }; "sort": { "alias": "sort"; "required": false; }; "sortFn": { "alias": "sortFn"; "required": false; }; "tableName": { "alias": "tableName"; "required": false; }; "pagination": { "alias": "pagination"; "required": false; }; "expansion": { "alias": "expansion"; "required": false; }; "expandedAriaLabel": { "alias": "expandedAriaLabel"; "required": false; }; "collapsedAriaLabel": { "alias": "collapsedAriaLabel"; "required": false; }; "headerColor": { "alias": "headerColor"; "required": false; }; }, { "expansionClicked": "expansionClicked"; "rowClicked": "rowClicked"; }, ["sdsTableRowComponent", "sdsTableHeaderRowComponent", "sdsTableFooterRowComponent", "sdsColumnItems"], never, false, never>;
}
